==> openshift-model-machineconfig-6.9.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ImageRegistryBundleFluent.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageRegistryBundleFluent<A extends ImageRegistryBundleFluent<A>> extends BaseFluent<A>{
  public ImageRegistryBundleFluent() {
  }
  
  public ImageRegistryBundleFluent(ImageRegistryBundle instance) {
    this.copyInstance(instance);
  }
  private String data;
  private String file;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageRegistryBundle instance) {
    instance = (instance != null ? instance : new ImageRegistryBundle());
  
    if (instance != null) {
        this.withData(instance.getData());
        this.withFile(instance.getFile());
        this.withData(instance.getData());
        this.withFile(instance.getFile());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getData() {
    return this.data;
  }
  
  public A withData(String data) {
    this.data=data; return (A) this;
  }
  
  public boolean hasData() {
    return this.data != null;
  }
  
  public String getFile() {
    return this.file;
  }
  
  public A withFile(String file) {
    this.file=file; return (A) this;
  }
  
  public boolean hasFile() {
    return this.file != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryBundleFluent that = (ImageRegistryBundleFluent) o;
    if (!java.util.Objects.equals(data, that.data)) return false;
  
    if (!java.util.Objects.equals(file, that.file)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(data,  file,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (data != null) { sb.append("data:"); sb.append(data + ","); }
    if (file != null) { sb.append("file:"); sb.append(file + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-machineconfig-6.9.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ImageRegistryBundleFluent.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageRegistryBundleFluent<A extends ImageRegistryBundleFluent<A>> extends BaseFluent<A>{
  public ImageRegistryBundleFluent() {
  }
  
  public ImageRegistryBundleFluent(ImageRegistryBundle instance) {
    this.copyInstance(instance);
  }
  private String data;
  private String file;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageRegistryBundle instance) {
    instance = (instance != null ? instance : new ImageRegistryBundle());
    if (instance != null) {
          this.withData(instance.getData());
          this.withFile(instance.getFile());
          this.withData(instance.getData());
          this.withFile(instance.getFile());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getData() {
    return this.data;
  }
  
  public A withData(String data) {
    this.data = data;
    return (A) this;
  }
  
  public boolean hasData() {
    return this.data != null;
  }
  
  public String getFile() {
    return this.file;
  }
  
  public A withFile(String file) {
    this.file = file;
    return (A) this;
  }
  
  public boolean hasFile() {
    return this.file != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryBundleFluent that = (ImageRegistryBundleFluent) o;
    if (!java.util.Objects.equals(data, that.data)) return false;
    if (!java.util.Objects.equals(file, that.file)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(data,  file,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (data != null) { sb.append("data:"); sb.append(data + ","); }
    if (file != null) { sb.append("file:"); sb.append(file + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
